
# TensorQuant

![tQuant Logo](https://img.shields.io/badge/tQuant-v0.1.0-blue.svg) ![Python](https://img.shields.io/badge/python-v3.7+-blue.svg) ![Build Status](https://img.shields.io/badge/build-passing-brightgreen.svg) ![License](https://img.shields.io/badge/license-MIT-green.svg)


**TensorQuant** is a Python financial library designed to provide students with a practical, Python-based alternative to traditional C++ implementations. Leveraging Tensor arrays, TensorQuant supports pricing, intensive risk management computations, and algorithmic differentiation. It is particularly valuable in academic settings, such as the Quant-Finance Master courses at the [University of Siena](https://finance.unisi.it/it), where it offers students hands-on experience with financial libraries and object-oriented programming during their final year.

Many of the objects in TensorQuant draw inspiration from the renowned [QuantLib](https://www.quantlib.org) library. We extend our gratitude to the QuantLib community for their foundational contributions to financial modeling. While many design patterns have been simplified for ease of understanding, TensorQuant strikes a balance between code complexity and professional architecture.


## Table of Contents

- [Features](#features)
- [Installation](#installation)
- [Usage](#usage)
- [Contributing](#contributing)
- [License](#license)
- [Contact](#contact)

## Features

- **Tensor Array Operations**: Efficient handling and manipulation of tensor arrays for financial data.
- **Risk Management**: Tools for advanced risk assessment and management.
- **Algorithmic Differentiation**: Capabilities for automatic differentiation to aid in optimization and sensitivity analysis.
- **Extensibility**: Easy to extend and customize for various financial applications.
- **Performance**: Optimized for high-performance computations.

## Installation
TBD
To install `TensorQuant`, simply use pip:

```bash
pip install tensorquant
```

Or, if you prefer, clone the repository and install manually:

```bash
git clone https://github.com/andrea220/tQuant.git
cd tQuant
pip install .
```

## Usage
TBD
<!-- Here you can find basic examples of how to use `tQuant`:

### General Objects
- [**`Time handles`**](https://github.com/andrea220/tQuant/blob/main/examples/time_handles.ipynb): how to use time handles.
- [**`Index`**](https://github.com/andrea220/tQuant/blob/main/examples/index.ipynb): how to create index objects.
- [**`Market data`**](https://github.com/andrea220/tQuant/blob/main/examples/market_data.ipynb): how to handle market data.

### Interest Rate and Credit:
- [**`Coupons`**](https://github.com/andrea220/tQuant/blob/main/examples/coupons.ipynb): how to handle fixed/floating coupons and legs.
- [**`Coupon pricer`**](https://github.com/andrea220/tQuant/blob/main/examples/coupons_pricer.ipynb): price and sensitivities of fixed/floating coupons and legs.
- [**`Forward rate agreement`**](https://github.com/andrea220/tQuant/blob/main/examples/fra.ipynb): price and sensitivities of Forward Rate Agreement.
- [**`Interest rate swaps`**](https://github.com/andrea220/tQuant/blob/main/examples/swap.ipynb): price and sensitivities of interest rate swaps.
- [**`Bootstrapping`**](https://github.com/andrea220/tQuant/blob/main/examples/bootstrapping.ipynb): bootstrapping example.
- [**`Credit default swaps`**](https://github.com/andrea220/tQuant/blob/main/examples/cds.ipynb): price and sensitivities of credit default swaps.
- [**`Hull and White model`**](https://github.com/andrea220/tQuant/blob/main/examples/hullwhite.ipynb): simulation of the Hull and White model. -->



<!-- For more detailed usage and examples, please refer to the [documentation](https://github.com/yourusername/tQuant/wiki). -->

## Contributing

<!-- We welcome contributions to `tQuant`! If you're interested in contributing, please read our [contributing guidelines](CONTRIBUTING.md) to get started. -->
TBD 

## License

`TensorQuant` is licensed under the GPL-3.0 License. See the [LICENSE](LICENSE) file for more details.

## Contact

For any questions or suggestions, feel free to reach out:

- **Email**: [carapelliandrea@gmail.com](mailto:carapelliandrea@gmail.com)
<!-- - **GitHub Issues**: [tQuant Issues](https://github.com/yourusername/tQuant/issues) -->

Happy computing!
